# TrackedConversationEventIdentifierDescriptionPairs

These are all of the available event types that are permitted in an object pair notation.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**var_schema** | [**EmbeddedModelSchema**](EmbeddedModelSchema.md) |  | [optional] 
**conversation_created** | **str** | The key value pair for an conversation being created. | [optional] 
**conversation_referenced** | **str** | This means that an conversation was view/used while the user was looking at the default view. | [optional] 
**conversation_deleted** | **str** | A conversation was deleted | [optional] 
**conversation_summary_annotation_generated_by_the_user** | **str** | A conversation summary was generated by the user | [optional] 
**conversation_name_updated_by_the_system** | **str** | A conversation was renamed by the system | [optional] 
**conversation_name_updated_by_the_user** | **str** | A conversation was renamed by the user | [optional] 
**conversation_summary_annotation_generated_by_the_system** | **str** | A conversation summary was generated | [optional] 

## Example

```python
from openapi_client.models.tracked_conversation_event_identifier_description_pairs import TrackedConversationEventIdentifierDescriptionPairs

# TODO update the JSON string below
json = "{}"
# create an instance of TrackedConversationEventIdentifierDescriptionPairs from a JSON string
tracked_conversation_event_identifier_description_pairs_instance = TrackedConversationEventIdentifierDescriptionPairs.from_json(json)
# print the JSON string representation of the object
print TrackedConversationEventIdentifierDescriptionPairs.to_json()

# convert the object into a dict
tracked_conversation_event_identifier_description_pairs_dict = tracked_conversation_event_identifier_description_pairs_instance.to_dict()
# create an instance of TrackedConversationEventIdentifierDescriptionPairs from a dict
tracked_conversation_event_identifier_description_pairs_form_dict = tracked_conversation_event_identifier_description_pairs.from_dict(tracked_conversation_event_identifier_description_pairs_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


